@@ -11,22 +11,16 @@ from cryptography.x509.ocsp import OCSPResponseStatus
 
 from sslyze.plugins.certificate_info._cert_chain_analyzer import CertificateDeploymentAnalysisResult
 from sslyze.plugins.certificate_info._certificate_utils import get_common_names, extract_dns_subject_alternative_names
-from sslyze.plugins.certificate_info._json_output import (
-    oid_to_json,
-    x509_name_to_json,
-    x509_certificate_to_json,
-    ocsp_response_to_json,
-)
+
 from sslyze.plugins.plugin_base import ScanCommandCliConnector, OptParseCliOption
 
 if TYPE_CHECKING:
     from sslyze.plugins.certificate_info.implementation import CertificateInfoScanResult
-    from sslyze.plugins.certificate_info.implementation import CertificateInfoExtraArguments  # noqa: F401
-    from sslyze.json import JsonSerializerFunction  # noqa: F401
+    from sslyze.plugins.certificate_info.implementation import CertificateInfoExtraArgument  # noqa: F401
 
 
 class _CertificateInfoCliConnector(
-    ScanCommandCliConnector["CertificateInfoScanResult", "CertificateInfoExtraArguments"]
+    ScanCommandCliConnector["CertificateInfoScanResult", "CertificateInfoExtraArgument"]
 ):
 
     _cli_option = "certinfo"
@@ -38,8 +32,8 @@ class _CertificateInfoCliConnector(
         scan_command_option.append(
             OptParseCliOption(
                 option="certinfo_ca_file",
-                help="Path to a file containing root certificates in PEM format that will be used to verify the"
-                " validity of the server's certificate.",
+                help="To be used with --certinfo. Path to a file containing root certificates in PEM format that will"
+                " be used to verify the validity of the server's certificate.",
                 action="store",
             )
         )
@@ -48,9 +42,9 @@ class _CertificateInfoCliConnector(
     @classmethod
     def find_cli_options_in_command_line(
         cls, parsed_command_line: Dict[str, Union[None, bool, str]]
-    ) -> Tuple[bool, Optional["CertificateInfoExtraArguments"]]:
+    ) -> Tuple[bool, Optional["CertificateInfoExtraArgument"]]:
         # Avoid circular imports
-        from sslyze.plugins.certificate_info.implementation import CertificateInfoExtraArguments  # noqa: F811
+        from sslyze.plugins.certificate_info.implementation import CertificateInfoExtraArgument  # noqa: F811
 
         # Check if --certinfo was used
         is_scan_cmd_enabled, _ = super().find_cli_options_in_command_line(parsed_command_line)
@@ -62,16 +56,12 @@ class _CertificateInfoCliConnector(
             if certinfo_ca_file:
                 if not isinstance(certinfo_ca_file, str):
                     raise TypeError(f"Expected a str for certinfo_ca_file but received {certinfo_ca_file}")
-                extra_arguments = CertificateInfoExtraArguments(custom_ca_file=Path(certinfo_ca_file))
+                extra_arguments = CertificateInfoExtraArgument(custom_ca_file=Path(certinfo_ca_file))
         except KeyError:
             pass
 
         return is_scan_cmd_enabled, extra_arguments
 
-    @classmethod
-    def get_json_serializer_functions(cls) -> List["JsonSerializerFunction"]:
-        return [oid_to_json, x509_name_to_json, x509_certificate_to_json, ocsp_response_to_json]
-
     TRUST_FORMAT = "{store_name} CA Store ({store_version}):"
     NO_VERIFIED_CHAIN_ERROR_TXT = "ERROR - Could not build verified chain (certificate untrusted?)"
 
@@ -337,8 +327,7 @@ def _get_issuer_as_short_text(certificate: Certificate) -> str:
 
 
 def _get_name_as_short_text(name_field: x509.Name) -> str:
-    """Convert a name field returned by the cryptography module to a string suitable for displaying it to the user.
-    """
+    """Convert a name field returned by the cryptography module to a string suitable for displaying it to the user."""
     # Name_field is supposed to be a Subject or an Issuer; print the CN if there is one
     common_names = get_common_names(name_field)
     if common_names:
