@@ -69,8 +69,7 @@ class _RobotCliConnector(ScanCommandCliConnector[RobotScanResult, None]):
 
 
 class RobotImplementation(ScanCommandImplementation[RobotScanResult, None]):
-    """Test a server for the ROBOT vulnerability.
-    """
+    """Test a server for the ROBOT vulnerability."""
 
     cli_connector_cls = _RobotCliConnector
 
