@@ -76,8 +76,7 @@ class _SessionRenegotiationCliConnector(ScanCommandCliConnector[SessionRenegotia
 
 
 class SessionRenegotiationImplementation(ScanCommandImplementation[SessionRenegotiationScanResult, None]):
-    """Test a server for insecure TLS renegotiation and client-initiated renegotiation.
-    """
+    """Test a server for insecure TLS renegotiation and client-initiated renegotiation."""
 
     cli_connector_cls = _SessionRenegotiationCliConnector
 
@@ -114,8 +113,7 @@ class SessionRenegotiationImplementation(ScanCommandImplementation[SessionRenego
 
 
 def _test_secure_renegotiation(server_info: ServerConnectivityInfo) -> Tuple[_ScanJobResultEnum, bool]:
-    """Check whether the server supports secure renegotiation.
-    """
+    """Check whether the server supports secure renegotiation."""
     # Try with TLS 1.2 even if the server supports TLS 1.3 or higher as there is no reneg with TLS 1.3
     if server_info.tls_probing_result.highest_tls_version_supported.value >= TlsVersionEnum.TLS_1_3.value:
         tls_version_to_use = TlsVersionEnum.TLS_1_2
@@ -150,8 +148,7 @@ def _test_secure_renegotiation(server_info: ServerConnectivityInfo) -> Tuple[_Sc
 
 
 def _test_client_renegotiation(server_info: ServerConnectivityInfo) -> Tuple[_ScanJobResultEnum, bool]:
-    """Check whether the server honors session renegotiation requests.
-    """
+    """Check whether the server honors session renegotiation requests."""
     # Try with TLS 1.2 even if the server supports TLS 1.3 or higher as there is no reneg with TLS 1.3
     if server_info.tls_probing_result.highest_tls_version_supported.value >= TlsVersionEnum.TLS_1_3.value:
         tls_version_to_use = TlsVersionEnum.TLS_1_2
